@@ -2,6 +2,7 @@
 
 import json
 import os
+import subprocess
 import sys
 import urllib.request
 from urllib.error import HTTPError
@@ -11,8 +12,10 @@ from pre_commit.main import main as pre_commit_run
 
 from repo_stream.git import (
     git_add_all_commit,
+    git_add_remote,
     git_push,
     git_random_checkout,
+    git_set_remote_url,
     repo_default_branch_name,
     there_are_untracked_changes,
     tmp_repo,
@@ -197,6 +200,7 @@ def update(
     usernames,
     include_forks=False,
     branch_prefix="repo-stream--",
+    repositories_to_ignore=[],
     dry_run=False,
 ):
     """Update repositories which have a repo-stream pre-commit config searching
@@ -209,13 +213,20 @@ def update(
     usernames : list
       Users for which to get repositories.
 
-    dry_run : bool, optional
-      Don't make pull requests, just prints to STDOUT when pull requests would
-      be opened.
-
     include_forks : bool, optional
       Include forks of repositories stored by the user in its Github account.
 
+    branch_prefix : str, optional
+      Branch name prefix used for creating the patches. Opened pull requests
+      will use that branch name to make changes.
+
+    repositories_to_ignore : list, optional
+      Repositories full names to ignore from being checked for repo-stream
+      pre-commit hooks.
+
+    dry_run : bool, optional
+      Don't make pull requests, just prints to STDOUT when pull requests would
+      be opened.
 
     Returns
     -------
@@ -224,12 +235,16 @@ def update(
     """
     update_exitcode = 0
 
+    gh_username = os.environ.get("GITHUB_USERNAME")
+    gh_token = os.environ.get("GITHUB_TOKEN")
+
     for user_i, username in enumerate(usernames):
         sys.stdout.write(f"Processing '{username}' user: ")
         try:
             user_repos = get_user_repos(
                 username,
                 fork=False if not include_forks else None,
+                repositories_to_ignore=repositories_to_ignore,
             )
         except HTTPError as err:
             if err.code == 404:
@@ -243,10 +258,10 @@ def update(
             msg = f"{n_user_repos}"
             if not include_forks:
                 msg += " non forked"
-            msg += " repositories found.\n"
+            msg += " repositories will be checked.\n"
             sys.stdout.write(msg)
         else:
-            msg = "No repositories found.\n"
+            msg = "No repositories will be checked.\n"
             sys.stdout.write(msg)
             continue
 
@@ -263,7 +278,9 @@ def update(
         for repo in repos_stream_config:
             sys.stdout.write(f"Cloning '{repo['repo']}'...\n")
 
-            with tmp_repo(repo["repo"]) as repo_dirpath:
+            with tmp_repo(
+                repo["repo"], username=gh_username, token=gh_token
+            ) as repo_dirpath:
                 config_filepath = os.path.join(
                     os.path.abspath(os.path.dirname(repo_dirpath)),
                     "._pre-commit-config.yaml",
@@ -294,6 +311,21 @@ def update(
 
                     if not _pull_request_opened:
                         # pull request
+                        try:
+                            git_add_remote(
+                                repo["repo"],
+                                gh_username,
+                                gh_token,
+                                remote="origin",
+                            )
+                        except subprocess.CalledProcessError:
+                            pass
+                        git_set_remote_url(
+                            repo["repo"],
+                            gh_username,
+                            gh_token,
+                            remote="origin",
+                        )
                         git_add_all_commit(title="repo-stream update")
                         git_push("origin", new_branch_name)
                         sys.stdout.write(f"Pushed branch '{new_branch_name}'")
